<?php

////////////////////////////////////////////////////////////////////////
//
// Function definitions necessary to create XML/VOTABLE files.
//
///////////////////////////////////////////////////////////////////////

function print_column_headers_VO() {

  /// PRINT VOTABLE HEADERS (<FIELD>) FOR EACH OF THE COLUMNS TO BE INCLUDED

  echo "  <FIELD name=\"Filename\" ID=\"col1\" ucd=\"meta.id;meta.main\" datatype=\"char\" arraysize=\"30\">\n";
  echo "   <DESCRIPTION>\n    This is the name of the PSRFITS file at this position.\n   </DESCRIPTION>\n  </FIELD>\n";

  echo "  <FIELD name=\"Distance\" ID=\"col2\" ucd=\"pos.angDistance\" datatype=\"double\" width=\"10\" precision=\"4\" unit=\"deg\">\n";
  echo "   <DESCRIPTION>\n   The angular separation from the queried position.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"Target Name\" ID=\"col3\" ucd=\"obs.field;meta.id\" datatype=\"char\" arraysize=\"20\">\n";
  echo "   <DESCRIPTION>\n    This is the name of the PSRFITS file at this position.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"Survey\" ID=\"col4\" ucd=\"obs;meta.dataset;meta.id\" datatype=\"char\" arraysize=\"10\">\n";
  echo "   <DESCRIPTION>\n    The short code for the survey type: PKS70=70cm Parkes Southern Pulsar Survey; PM=Parkes Multibeam Pulsar Survey, PH=Parkes High-Latitude Pulsar Survey; blank means not part of a survey or unknown.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"RA\" ID=\"col5\" ucd=\"pos.eq.ra;meta.main\" ref=\"J2000\" datatype=\"double\" width=\"10\" precision=\"6\" unit=\"deg\">\n";
  echo "   <DESCRIPTION>\n    The Right Ascension of the central position of the pointing.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"DEC\" ID=\"col6\" ucd=\"pos.eq.dec;meta.main\" ref=\"J2000\" datatype=\"double\" width=\"11\" precision=\"6\" unit=\"deg\">\n";
  echo "   <DESCRIPTION>\n    The Declination of the central position of the pointing.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"BMAJ\" ID=\"col7\" ucd=\"pos.angResolution;phys.angSize.smajAxis\" datatype=\"float\" width=\"6\" precision=\"4\" unit=\"deg\">\n";
  echo "   <DESCRIPTION>\n    The full-width-half-maximum (FWHM) of the major-axis of the beam.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"BMIN\" ID=\"col8\" ucd=\"pos.angResolution;phys.angSize.sminAxis\" datatype=\"float\" width=\"6\" precision=\"4\" unit=\"deg\">\n";
  echo "   <DESCRIPTION>\n    The full-width-half-maximum (FWHM) of the minor-axis of the beam.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"BPA\" ID=\"col9\" ucd=\"pos.angResolution;pos.posAng\" datatype=\"float\" width=\"6\" precision=\"4\" unit=\"deg\">\n";
  echo "   <DESCRIPTION>\n    The position angle of the beam.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"UT Date of Observations\" ID=\"col10\" ucd=\"time.start\" datatype=\"char\" arraysize=\"30\">\n";
  echo "   <DESCRIPTION>\n    The UT Date of the start of the observation.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"UT Time of Observations\" ID=\"col11\" ucd=\"time.start\" datatype=\"char\" arraysize=\"30\">\n";
  echo "   <DESCRIPTION>\n    The UT Time of the start of the observation.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"MJD\" ID=\"col12\" ucd=\"time.start\" datatype=\"double\" width=\"14\" precision=\"8\">\n";
  echo "   <DESCRIPTION>\n    The Modified Julian Date of the observation.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"ObsFreq\" ID=\"col13\" ucd=\"em.freq.central\" datatype=\"double\" width=\"9\" precision=\"4\" unit=\"MHz\">\n";
  echo "   <DESCRIPTION>\n    The central observing frequency.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"Channel Bandwidth\" ID=\"col14\" ucd=\"spect.binSize;em.freq\" datatype=\"double\" width=\"9\" precision=\"4\" unit=\"MHz\">\n";
  echo "   <DESCRIPTION>\n    The frequency width of each channel.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"Number of Channels\" ID=\"col15\" ucd=\"em.bin;meta.number\" datatype=\"int\" width=\"6\">\n";
  echo "   <DESCRIPTION>\n    The number of frequency channels.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"Scan length\" ID=\"col16\" ucd=\"obs.exposure;time.duration\" datatype=\"float\" width=\"9\" precision=\"4\" unit=\"s\">\n";
  echo "   <DESCRIPTION>\n    The total length of time taken for this observation.\n   </DESCRIPTION>\n  </FIELD>\n";
  
  echo "  <FIELD name=\"Sample time\" ID=\"col17\" ucd=\"time.resolution\" datatype=\"float\" width=\"9\" precision=\"4\" unit=\"s\">\n";
  echo "   <DESCRIPTION>\n    The time for each sample in the observation.\n   </DESCRIPTION>\n  </FIELD>\n";
   
}

function print_data_VO($all_results) {
  
  echo "  <DATA>\n   <TABLEDATA>\n";
  for ($i=0; $i < count($all_results); $i++) {
    $line = $all_results[$i];
    print_data_line_VO($line);
  }
  echo "   </TABLEDATA>\n  </DATA>\n";

}

function print_data_line_VO($line) {
  // PRINT A SINGLE ROW OF DATA TO THE VOTABLE
  echo "    <TR>\n ";
  print_datum($line['filename'],"%s");
  print_datum($line['angsep'],"%8.6f");
  print_datum($line['src_name'],"%s");
  print_datum($line['survey'],"%s");
  print_datum($line['rajd'],"%10.6f");
  print_datum($line['decjd'],"%+11.6f");
  print_datum($line['bmaj'],"%6.4f");
  print_datum($line['bmin'],"%6.4f");
  print_datum($line['bpa'],"%6.4f");
  print_datum($line['date'],"%s");
  print_datum($line['ut'],"%s");
  print_datum($line['MJD'],"%14.8f");
  print_datum($line['obsfreq'],"%9.4f");
  print_datum($line['bw'],"%9.4f");
  print_datum($line['nchan'],"%d");
  print_datum($line['scanlen'],"%9.4f");
  print_datum($line['tsamp'],"%9.4f");
  echo "\n    </TR>\n";
}

function print_datum($datum, $format)
{
  if($datum == "NULL" || $datum == "") printf("     <TD></TD>");
  else {
    $output = "     <TD>".$format."</TD>";
    printf($output,$datum);
  }

}

?>
